
User-visible changes in "magic-wormhole-mailbox-server":

## Release 0.3.0 (23-Jun-2018)

Fix munin plugins, record client versions in usageDB.


## Release 0.2.0 (16-Jun-2018)

Improve install docs, clean up Munin plugins, add DB migration tool.


## Release 0.1.0 (19-Feb-2018)

Initial release: Forked from magic-wormhole-0.10.5 (14-Feb-2018)
